'use strict';

exports.__esModule = true;

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var translations = {
  'Mobile verification code': '手机验证码',
  'Verification code has been sent to {value}': '验证码已发送至{value}',
  'Click to resend': '点击重新发送',
  'Resend in {value}s': '{value}秒后重新发送'
};

var KeycodeInput = function (_Component) {
  _inherits(KeycodeInput, _Component);

  function KeycodeInput() {
    var _temp, _this, _ret;

    _classCallCheck(this, KeycodeInput);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.inputs = [], _this.state = {
      codes: _lodash2.default.times(_this.props.codeLength, _lodash2.default.constant('')),
      timeLeft: 60
    }, _this.TR = function (str) {
      if (_this.props.lang === 'zh' && translations[str]) {
        return translations[str];
      } else {
        return str;
      }
    }, _this.inputChange = function (i) {
      return function (e) {
        var newValue = e.target.value;
        if (newValue.length > 1) {
          return;
        }
        if (_this.props.onlyNumber && newValue.length > 0 && !newValue.match(/[0-9]/)) {
          return;
        }
        var codes = _this.state.codes;
        codes[i] = newValue;
        _this.setState({ codes: codes });
        if (newValue !== '' && i + 1 < _this.inputs.length) {
          _this.inputs[i + 1].focus();
        } else if (newValue === '' && i - 1 >= 0) {
          _this.inputs[i - 1].focus();
        }
        _this.checkAndCommit();
      };
    }, _this.inputKeyDown = function (i) {
      return function (e) {
        if (e.key === 'Backspace' && _this.inputs[i].value === '' && i - 1 >= 0) {
          _this.inputs[i - 1].focus();
        }
      };
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  KeycodeInput.prototype.componentDidMount = function componentDidMount() {
    var _this2 = this;

    var initialSeconds = this.props.initialSeconds;

    this.setState({ timeLeft: initialSeconds });
    this.focusAtFirst();
    this.countDownTimer = setInterval(function () {
      if (_this2.state.timeLeft > 0) {
        _this2.setState({ timeLeft: _this2.state.timeLeft - 1 });
      }
    }, 1000);
  };

  KeycodeInput.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    if (!this.props.visible && nextProps.visible) {
      this.setState({ timeLeft: nextProps.initialSeconds });
      this.focusAtFirst();
    }
  };

  KeycodeInput.prototype.focusAtFirst = function focusAtFirst() {
    var _this3 = this;

    setTimeout(function () {
      var t = _this3.inputs[0];
      t && t.focus();
    }, 300);
  };

  KeycodeInput.prototype.componentWillUnmount = function componentWillUnmount() {
    clearInterval(this.countDownTimer);
  };

  KeycodeInput.prototype.updateInputRefs = function updateInputRefs(el, index) {
    this.inputs[index] = el;
  };

  KeycodeInput.prototype.checkAndCommit = function checkAndCommit() {
    var full = true;
    var code = '';
    for (var i = 0; i < this.inputs.length; i++) {
      var value = this.inputs[i].value;
      if (value === '') {
        full = false;
        break;
      } else {
        code += value;
      }
    }
    if (full && this.props.onComplete) {
      this.props.onComplete(code);
    }
  };

  KeycodeInput.prototype.render = function render() {
    var _this4 = this;

    var TR = this.TR;
    return _react2.default.createElement(
      'div',
      { style: this.props.style },
      _react2.default.createElement(
        'div',
        { style: { textAlign: 'center', fontSize: 14 } },
        TR('Mobile verification code')
      ),
      _react2.default.createElement(
        'div',
        { style: { textAlign: 'center', fontSize: 12, color: '#aaa' } },
        TR('Verification code has been sent to {value}').replace('{value}', this.props.mobile)
      ),
      _react2.default.createElement(
        'div',
        { style: { textAlign: 'center', margin: 10 } },
        _lodash2.default.map(_lodash2.default.range(this.props.codeLength), function (v, i) {
          return _react2.default.createElement('input', { key: i, onChange: _this4.inputChange(i),
            onKeyDown: _this4.inputKeyDown(i), value: _this4.state.codes[i],
            ref: function ref(el) {
              return _this4.updateInputRefs(el, i);
            },
            style: { width: 40, height: 40, margin: 8, display: 'inline-block', textAlign: 'center', fontSize: 20 } });
        })
      ),
      this.state.timeLeft === 0 ? _react2.default.createElement(
        'p',
        { style: { textAlign: 'center', cursor: 'pointer', fontSize: 12 }, onClick: function onClick() {
            if (_this4.props.onResend) {
              _this4.props.onResend();
              _this4.setState({ timeLeft: _this4.props.initialSeconds });
            }
          } },
        TR('Click to resend')
      ) : _react2.default.createElement(
        'p',
        { style: { textAlign: 'center', fontSize: 12 } },
        TR('Resend in {value}s').replace('{value}', this.state.timeLeft)
      )
    );
  };

  return KeycodeInput;
}(_react.Component);

KeycodeInput.propTypes = {
  lang: _propTypes2.default.string,
  mobile: _propTypes2.default.string,
  initialSeconds: _propTypes2.default.number,
  codeLength: _propTypes2.default.number,
  style: _propTypes2.default.object,
  visible: _propTypes2.default.bool,
  onlyNumber: _propTypes2.default.bool,
  onResend: _propTypes2.default.func,
  onComplete: _propTypes2.default.func
};
KeycodeInput.defaultProps = {
  codeLength: 4,
  initialSeconds: 60,
  onlyNumber: true,
  lang: 'en',
  style: {}
};
exports.default = KeycodeInput;